% ====================================================
% Matlab code equivalent to C calibration code.
%
% Copyright (C) 2000-2001 by K-Team, S.A. All rights reserved.
%
% Developed at K-Team S.A by Skye Legon.
%
% Permission to use, copy, modify, and distribute this
% software is freely granted, provided that this notice
% is preserved.
%
% There is no warranty for this free software.  If the software is modified
% by someone else and passed on, we want its recipients to know that
% what they have is not the original, so that any problems introduced
% by others will not reflect on the original authors' reputations.
%
% ====================================================

% open serial port
ref = kopen([0,38400,1]);

% grab image

fun_grab_image(ref)

% obtain image

rawimage = fun_download_image(ref);

% close serial port
kclose(ref);

figure(1);
fun_show_rawimage(im)
pause

% threshold image

threshold = 250;

dots = 0;
for col=1:size(im,2)
	for row=1:size(im,1)
		if im(row,col)>threshold
			dot = 0;
			% check for membership in each dot, stopping once a dot is assigned
			while ((dot+1)<=dots)&(im(row,col)>threshold)
				dot = dot + 1;
				if (abs(col-xproto(dot))< 20)&(abs(row-yproto(dot))< 20)
					im(row,col) = dot;
				end
			end
			% if no dot was assigned, create a new one
			if im(row,col)>threshold
				dots = dots + 1;
				dot = dots;
				xproto(dot) = col;
				yproto(dot) = row;
				xmean(dot) = 0;
				ymean(dot) = 0;
				points(dot) = 0;
				im(row,col) = dot;
			end
			xmean(dot) = xmean(dot) + col;
			ymean(dot) = ymean(dot) + row;
			points(dot) = points(dot) + 1;
		else
			im(row,col)=0;
		end
	end
end

disp(sprintf('Found %2d dots',dots))

for dot=1:dots
	xmean(dot) = floor(xmean(dot) / points(dot));
	ymean(dot) = floor(ymean(dot) / points(dot));
	disp(sprintf('Dot %2d: found %3d points centred at (%3d,%3d)',...
		dot, points(dot), xmean(dot), ymean(dot)))
end

hold on
plot(xmean,ymean,'r+')
hold off


